@@ -13,6 +13,8 @@ from luna.logging.azuremlLunaLogger import AzureMLLunaLogger
 
 import os
 import yaml
+import tempfile
+import json
 
 class AzureMLLunaUtils(BaseLunaUtils):
 
@@ -45,12 +47,13 @@ class AzureMLLunaUtils(BaseLunaUtils):
     def GetDeploymentConfig(self, tags, deployment_target=None, aks_cluster=None):
 
         # Read default deployment target and aks cluster info from the config files
-        if not deployment_target:
-            with open(self._luna_config['azureml']['workspace_config']) as file:
-                documents = yaml.full_load(file)
-                deployment_target = documents['deployment_target']
-                if deployment_target == 'aks':
-                    aks_cluster = documents['aks_cluster']
+        
+        workspace_full_path = os.path.join(self._luna_config['azureml']['test_workspace_path'], self._luna_config['azureml']['test_workspace_file_name'])
+        with open(workspace_full_path) as file:
+            documents = json.load(file)
+            deployment_target = documents['DeploymentTarget']
+            if deployment_target == 'aks':
+                aks_cluster = documents['AksCluster']
 
         with open(self._luna_config['deploy_config']) as file:
             documents = yaml.full_load(file)
@@ -96,3 +99,49 @@ class AzureMLLunaUtils(BaseLunaUtils):
         os.makedirs(full_model_path, exist_ok=True)
         model.download(target_dir = full_model_path, exist_ok=True)
         return full_model_path
+
+    def FindPredecessorRun(self):
+        run = Run.get_context(allow_offline=False)
+        experiment = run.experiment
+        
+        tags={'userId': self._args.userId,
+              'subscriptionId':self._args.subscriptionId,
+              'operationId': self._args.predecessorOperationId}
+
+        runs = experiment.get_runs(type='azureml.PipelineRun', tags=tags)
+        return next(runs)
+
+    def GetJsonOutputFromPredecessorRun(self):
+        """
+        Get JSON output from predecessor run
+        """
+        predecessorRun = self.FindPredecessorRun()
+        with tempfile.TemporaryDirectory() as tmp:
+            path = os.path.join(tmp, self._args.predecessorOperationId, 'output.json')
+            predecessorRun.download_file('/outputs/output.json', path)
+            with open(path) as file:
+                return json.load(file)
+    
+    def DownloadOutputFilesFromPredecessorRun(self, targetFolder):
+        """
+        Download output files from predecessor run
+        """
+        predecessorRun = self.FindPredecessorRun()
+        predecessorRun.download_files(prefix = 'outputs', output_directory='targetFolder')
+
+    def WriteJsonOutput(self, content):
+        """
+        Write json output to current run
+        """
+        with tempfile.TemporaryDirectory() as tmp:
+            path = os.path.join(tmp, self._args.predecessorOperationId, 'output.json')
+            with open(path, 'w') as outfile:
+                json.dump(content, outfile)
+
+        self._logger.upload_artifacts(path, 'outputs/output.json')
+    
+    def UploadOutputFiles(self, sourceFolder):
+        """
+        Upload files to output of current run
+        """
+        self._logger.upload_artifacts(sourceFolder, 'outputs')
\ No newline at end of file
